@@ -58,12 +58,12 @@ public:
     /**
      * Creates new Activities object
      */
-    explicit Activities(QObject *parent = Q_NULLPTR);
+    explicit Activities(QObject *parent = nullptr);
 
     /**
      * Destroys this interface
      */
-    virtual ~Activities();
+    ~Activities() override;
 
     // workspace activities control
 public Q_SLOTS:
