@@ -31,9 +31,7 @@
 #include <QDBusReply>
 
 // KDE
-// #include <KCrash>
-// #include <KAboutData>
-// #include <KCmdLineArgs>
+#include <KCrash>
 #include <KPluginMetaData>
 #include <KPluginLoader>
 #include <ksharedconfig.h>
@@ -326,13 +324,7 @@ int main(int argc, char **argv)
     application.setApplicationName(QStringLiteral("ActivityManager"));
     application.setOrganizationDomain(QStringLiteral("kde.org"));
 
-    // KAboutData about("kactivitymanagerd", nullptr, ki18n("KDE Activity Manager"), "3.0",
-    //         ki18n("KDE Activity Management Service"),
-    //         KAboutData::License_GPL,
-    //         ki18n("(c) 2010, 2011, 2012 Ivan Cukic"), KLocalizedString(),
-    //         "http://www.kde.org/");
-
-    // KCmdLineArgs::init(argc, argv, &about);
+    KCrash::initialize();
 
     const auto arguments = application.arguments();
 
